==> magento-module-custom-attribute-serializable-graph-ql-0.1.3.zip: Model/Resolver/CreditMemo/SetCustomAttributesOnCreditMemo.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\CreditMemo;

use Magento\CustomAttributeSerializableGraphQl\Model\Resolver\InputArgumentValidator;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlAuthorizationException;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Exception\GraphQlNoSuchEntityException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Query\Uid;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Sales\Api\CreditmemoRepositoryInterface;

/**
 * Sets custom attributes on a credit memo
 */
class SetCustomAttributesOnCreditMemo implements ResolverInterface
{
    /**
     * @param Uid $uidEncoder
     * @param CreditmemoRepositoryInterface $creditMemoRepository
     * @param InputArgumentValidator $argumentValidator
     */
    public function __construct(
        private readonly Uid $uidEncoder,
        private readonly CreditmemoRepositoryInterface $creditMemoRepository,
        private readonly InputArgumentValidator $argumentValidator
    ) {
    }

    /**
     * Sets custom attributes on a credit memo
     *
     * @param Field $field
     * @param mixed $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     * @throws GraphQlInputException
     * @throws GraphQlAuthorizationException
     * @throws GraphQlNoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(Field $field, $context, ResolveInfo $info, array $value = null, array $args = null)
    {
        $inputArgs = $args['input'];
        $this->argumentValidator->validate($inputArgs, ['credit_memo_id'], ['credit_memo_id']);

        try {
            $creditMemoId = $this->uidEncoder->decode($inputArgs['credit_memo_id']);
            $creditMemo = $this->creditMemoRepository->get($creditMemoId);

            if ((int)$creditMemo->getOrder()->getCustomerId() !== (int)$context->getUserId()) {
                throw new GraphQlAuthorizationException(__('The credit memo doesn\'t belong to the customer.'));
            }

            $attrs = [];
            foreach ($inputArgs['custom_attributes'] as $attribute) {
                $attrs[$attribute['attribute_code']] = $attribute['value'];
            }
            $creditMemo->setCustomAttributes($attrs);
            $this->creditMemoRepository->save($creditMemo);

            return [
                'credit_memo' => [
                    'id' => base64_encode((string)$creditMemo->getId()),
                    'number' => $creditMemo->getIncrementId(),
                    'model' => $creditMemo,
                    'order' => $creditMemo->getOrder()
                ]
            ];
        } catch (NoSuchEntityException $e) {
            throw new GraphQlNoSuchEntityException(__('The credit memo doesn\'t exist.'));
        } catch (CouldNotSaveException $e) {
            throw new GraphQlInputException(__('Could not save the credit memo.'));
        }
    }
}

==> magento-module-custom-attribute-serializable-graph-ql-0.5.0.zip: Model/Resolver/CreditMemo/SetCustomAttributesOnCreditMemo.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\CreditMemo;

use Magento\CustomAttributeSerializableGraphQl\Model\Resolver\InputArgumentValidator;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlAuthorizationException;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Exception\GraphQlNoSuchEntityException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Query\Uid;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Sales\Api\CreditmemoRepositoryInterface;

/**
 * Sets custom attributes on a credit memo
 */
class SetCustomAttributesOnCreditMemo implements ResolverInterface
{
    /**
     * @param Uid $uidEncoder
     * @param CreditmemoRepositoryInterface $creditMemoRepository
     * @param InputArgumentValidator $argumentValidator
     */
    public function __construct(
        private readonly Uid $uidEncoder,
        private readonly CreditmemoRepositoryInterface $creditMemoRepository,
        private readonly InputArgumentValidator $argumentValidator
    ) {
    }

    /**
     * Sets custom attributes on a credit memo
     *
     * @param Field $field
     * @param mixed $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     * @throws GraphQlInputException
     * @throws GraphQlAuthorizationException
     * @throws GraphQlNoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(Field $field, $context, ResolveInfo $info, ?array $value = null, ?array $args = null)
    {
        $inputArgs = $args['input'];
        $this->argumentValidator->validate($inputArgs, ['credit_memo_id'], ['credit_memo_id']);

        try {
            $creditMemoId = $this->uidEncoder->decode($inputArgs['credit_memo_id']);
            $creditMemo = $this->creditMemoRepository->get($creditMemoId);

            if ((int)$creditMemo->getOrder()->getCustomerId() !== (int)$context->getUserId()) {
                throw new GraphQlAuthorizationException(__('The credit memo doesn\'t belong to the customer.'));
            }

            $attrs = [];
            foreach ($inputArgs['custom_attributes'] as $attribute) {
                $attrs[$attribute['attribute_code']] = $attribute['value'];
            }
            $creditMemo->setCustomAttributes($attrs);
            $this->creditMemoRepository->save($creditMemo);

            return [
                'credit_memo' => [
                    'id' => base64_encode((string)$creditMemo->getId()),
                    'number' => $creditMemo->getIncrementId(),
                    'model' => $creditMemo,
                    'order' => $creditMemo->getOrder()
                ]
            ];
        } catch (NoSuchEntityException $e) {
            throw new GraphQlNoSuchEntityException(__('The credit memo doesn\'t exist.'));
        } catch (CouldNotSaveException $e) {
            throw new GraphQlInputException(__('Could not save the credit memo.'));
        }
    }
}
